@@ -6,6 +6,15 @@
  *
  * As described in http://bugzilla.gnome.org/show_bug.cgi?id=457077 it
  * returns nothing.
+ *
+ * Some special characters need escaping. The tests should pass 100\%.
+ * Try a <ulink url="http://www.gtk.org/gtk-doc/#Top">link containing a # char</ulink>.
+ *
+ * <refsect2 id="dummy-id">
+ * <para>
+ * Second paragraph inside subsection.
+ * </para>
+ * </refsect2>
  */
 
 #include <glib.h>
@@ -122,14 +131,14 @@ const char* const * bug_552602 (void) {
   return NULL;
 }
 
-/** 
+/**
  * bug_574654a:
  *
  * http://bugzilla.gnome.org/show_bug.cgi?id=574654
  *
  * Returns: result
  */
-/** 
+/**
  * bug_574654b:
  * @offset: skip this many items
  *
@@ -142,12 +151,35 @@ int bug_574654a(void) {
 void bug_574654b(double offset) { }
 
 
+/**
+ * bug_580300a_get_type:
+ *
+ * http://bugzilla.gnome.org/show_bug.cgi?id=580300
+ */
 void bug_580300a_get_type(void) { }
 
+/**
+ * bug_580300b_get_type:
+ * @a: value
+ *
+ * http://bugzilla.gnome.org/show_bug.cgi?id=580300
+ */
 void bug_580300b_get_type(gint a) { }
 
+/**
+ * bug_580300c_get_type:
+ *
+ * http://bugzilla.gnome.org/show_bug.cgi?id=580300
+ */
 void bug_580300c_get_type() { }
 
+/**
+ * bug_580300d_get_type:
+ *
+ * http://bugzilla.gnome.org/show_bug.cgi?id=580300
+ *
+ * Returns: result
+ */
 int bug_580300d_get_type() { }
 
 
@@ -183,3 +215,28 @@ unsigned long int bug_602518b(void) {
 unsigned int bug_602518c(void) {
   return (unsigned int)0;
 }
+
+/**
+ * bug_607445:
+ * @a: parameter
+ * @n: parameter
+ *
+ * http://bugzilla.gnome.org/show_bug.cgi?id=607445
+ */
+long double bug_607445(long double **a, int n) {
+  return 2.0*n;
+}
+
+/**
+ * bug_610257:
+ * @der: parameter
+ * @len: parameter
+ *
+ * http://bugzilla.gnome.org/show_bug.cgi?id=610257
+ */
+signed long
+bug_610257 (const unsigned char *der, int *len)
+{
+  return 1L;
+}
+
